from django.contrib import admin

from .models import DataPooling, Measurement


class MeasurementInline(admin.TabularInline):
    model = Measurement


@admin.register(DataPooling)
class DataPoolingAdmin(admin.ModelAdmin):
    list_display = ('observer', 'last_value', 'last_time')
    inlines = [MeasurementInline]

    def last_value(self, instance):
        if not instance.last_measurement:
            return None

        return instance.last_measurement
    last_value.short_description = 'Last measurement'

    def last_time(self, instance):
        if not instance.last_time:
            return None

        return instance.last_time
    last_time.short_description = 'Time of measurement'



# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-19 20:10
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('howl', '0003_alert_value'),
    ]

    operations = [
        migrations.CreateModel(
            name='DataPooling',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('measurement', models.IntegerField()),
                ('observer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='howl.Observer')),
            ],
        ),
    ]
